import { isAuthenticated } from 'api/isAuthenticated';
import { useEffect, useState } from 'react';

/**
 * Custom hook that uses the call is_authenticated.
 * {@link isAuthenticated}
 *
 * @returns {boolean | null} isAuth: true if user is authenticated, false otherwise or null if the request has not finished.
 */
export const useAuth = (): [
  boolean,
  React.Dispatch<React.SetStateAction<boolean>>,
] => {
  let isMounted = true;
  const [isAuth, setIsAuth] = useState<boolean>(false);
  useEffect(() => {
    isAuthenticated().then((state) => {
      if (isMounted) {
        setIsAuth(state);
      }
    });

    return () => {
      isMounted = false;
    };
  }, []);
  return [isAuth, setIsAuth];
};
